---
# SPDX-License-Identifier: CC0-1.0
# SPDX-FileCopyrightText: 2019-2023 The Foundation for Public Code <info@publiccode.net>, https://standard.publiccode.net/AUTHORS
order: 8
redirect_from:
  - criteria/document-objectives
---
# Document codebase objectives

Clearly documenting [codebase](../glossary.md#codebase) objectives communicates the purpose of the codebase.
It helps stakeholders and contributors scope the development of the codebase.
The objectives also provide an easy way for people to decide whether this codebase, or one of its modules, is interesting for them now or in the future.

## Requirements

* The codebase MUST contain documentation of its objectives, like a mission and goal statement, that is understandable by developers and designers so that they can use or contribute to the codebase.
* Codebase documentation SHOULD clearly describe the connections between [policy](../glossary.md#policy) objectives and codebase objectives.
* Documenting the objectives of the codebase for the [general public](../glossary.md#general-public) is OPTIONAL.

## How to test

* Confirm that the codebase documentation includes the codebase objectives, mission or goal.
* Check for descriptions of connections between policy objectives and codebase objectives.

## Public policy makers: what you need to do

* Add the policy objectives to the codebase documentation, for example in the `README`.
* Make sure that all your codebase objectives have links or references to supporting policy documents added to meet the [Bundle policy and source code](bundle-policy-and-source-code.md) criterion.

## Managers: what you need to do

* Add the organizational and business objectives to the codebase documentation, for example in the `README`.

## Developers and designers: what you need to do

* Add the technology and design objectives to the codebase documentation, for example in the `README`.

## Further reading

* [How to write project objectives](http://grouper.ieee.org/groups/802/3/RTPGE/public/may12/hajduczenia_01_0512.pdf) by Marek Hajduczenia.
